# -*- coding: utf-8 -*-
'''
    :file: config.py
    :author: -Farmer
    :url: https://blog.farmer233.top
    :date: 2021/09/04 23:39:20
'''
URL_ENDPOINT = {
    "HOME_URL": "/xtgl/login_slogin.html",
    'LOGIN': {
        'INDEX': '/xtgl/login_slogin.html',
        'CAPTCHA': '/zfcaptchaLogin',
        'KCAPTCHA': '/kaptcha',
        'PUBLIC_KEY': '/xtgl/login_getPublicKey.html',
    },
    "SCORE_URL": "",
    "INFO_URL": "",
    "SCHEDULE": {
        "API": '/kbcx/xskbcx_cxXsKb.html',
    },
    'SCORE': {
        'API': '/cjcx/cjcx_cxDgXscj.html'
    },
    'INFO': {
        'API': '/xsxxxggl/xsgrxxwh_cxXsgrxx.html'
    }
}
